@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/nickle.h,v 1.116 2004/05/13 21:16:52 bart Exp $ */
+/* $Header: /local/src/CVS/nickle/nickle.h,v 1.117 2004/05/28 02:58:14 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -772,15 +772,15 @@ IntBinaryOperate (Value av, Value bv, BinaryOp operator) {
     signed_digit rd;
     switch (operator) {
     case PlusOp:
-	r = ValueUInt(av) + ValueUInt(bv);
+	r = ValueInt(av) + ValueInt(bv);
 
-	if (r & NICKLE_INT_CARRY)
+	if (NICKLE_INT_CARRIED(r))
 	    return Plus (NewIntInteger (ValueInt(av)), NewIntInteger(ValueInt(bv)));
 	return NewInt(r);
     case MinusOp:
-	r = ValueUInt(av) - ValueUInt(bv);
+	r = ValueInt(av) - ValueInt(bv);
 
-	if (r & NICKLE_INT_CARRY)
+	if (NICKLE_INT_CARRIED(r))
 	    return Minus (NewIntInteger (ValueInt(av)), NewIntInteger(ValueInt(bv)));
 	return NewInt(r);    
     case TimesOp:
@@ -886,7 +886,7 @@ IntIncDec (Value av, BinaryOp operator)
 	a++;
     else
 	a--;
-    if ((a << 1 ^ a) & NICKLE_INT_CARRY)
+    if (NICKLE_INT_CARRIED(a))
 	return NewIntInteger (a);
     return NewInt (a);
 }
